[![Downloads](https://pepy.tech/badge/macapype)](https://pepy.tech/project/macapype)
[![Build Status](https://travis-ci.com/Macatools/macapype.svg?branch=master)](https://travis-ci.com/Macatools/macapype)

# Quick Install
To use it:
```shell
pip install macapype
```

To develop:
```shell
git clone https://github.com/Macatools/macapype.git
cd macapype
python setup.py develop
```

# Docker image
```shell
docker pull macatools/macapype/latest
```

# Documentation

https://macatools.github.io/macapype/

# Related to project:

[A guide for PNH MRI processing](https://github.com/PRIME-RE/prime-re.github.io/wiki), and in particular, the session on [structural MRI processing](https://github.com/PRIME-RE/prime-re.github.io/wiki/Structural-processing)

[Open Science Room OSR 2020 of OHBM congress presentation of macapype](https://docs.google.com/presentation/d/11RrcZW25MyLbc0_9T2zzhwy5RyUvcjYG4UAgzjuuv8M/edit?usp=sharing)


# Forum macapype_users

The macapype_users can be be found [here](https://framateam.org/signup_user_complete/?id=ebtxf45nmiyqmkm8e6oh9qjsoe) (requires a framateam/framagit account, but should be accessible with a github or bitbucket account)

